@@ -15,6 +15,12 @@ print "Circle perimeter = ", &shapes::Shape_perimeter($c), "\n\n";
 print "Square area      = ", &shapes::Shape_area($s), "\n";
 print "Square perimeter = ", &shapes::Shape_perimeter($s), "\n\n";
 
+# Try a function in the base class
+
+&shapes::Shape_print_center($c);
+&shapes::Circle_print_center($c);
+
+
 
 
 
