@@ -4,6 +4,9 @@
 # C, Tcl, associative arrays etc...
 #
 
+catch {load ./tree.so tree}
+catch {load ./tree.dll tree}
+
 set tree_head [new_node "" head]
 set tree_z    [new_node __end__ ""]
 set_right $tree_head $tree_z
