@@ -1,16 +1,16 @@
 
-/**********************************************************************
+/*******************************************************************************
  * Simplified Wrapper and Interface Generator  (SWIG)
  * 
  * Dave Beazley
  * 
- * Theoretical Division (T-11)           Department of Computer Science
- * Los Alamos National Laboratory        University of Utah
- * Los Alamos, New Mexico  87545         Salt Lake City, Utah  84112
- * beazley@lanl.gov                      beazley@cs.utah.edu
+ * Department of Computer Science        Theoretical Division (T-11)
+ * University of Utah                    Los Alamos National Laboratory
+ * Salt Lake City, Utah  84112           Los Alamos, New Mexico  87545
+ * beazley@cs.utah.edu                   beazley@lanl.gov
  *
- * Copyright (c) 1995-1996
- * The Regents of the University of California and the University of Utah
+ * Copyright (c) 1995-1997
+ * The University of Utah and the Regents of the University of California
  * All Rights Reserved
  *
  * Permission is hereby granted, without written agreement and without
@@ -38,11 +38,8 @@
  * THE AUTHORS AND DISTRIBUTORS HAVE NO OBLIGATION TO PROVIDE MAINTENANCE,
  * SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
  *
- * The author requests that all users of this software return any
- * improvements made to beazley@cs.utah.edu and grant the author
- * full redistribution rights.
- *
- **************************************************************************/
+ *******************************************************************************/
+
 /**************************************************************************
  * class TCL
  *
@@ -61,8 +58,42 @@ private:
   int    Plugin;
   int    nspace;
   char  *safe_name;
-  void   get_pointer(char *iname, int parm, DataType *t);
+  void   get_pointer(char *iname, char *srcname, char *src, char *dest, DataType *t,
+		     String &f, char *ret);
   char  *char_result;
+  char  *usage_string(char *, DataType *, ParmList *);
+  char  *usage_func(char *, DataType *, ParmList *);
+  char  *usage_var(char *, DataType *);
+  char  *usage_const(char *, DataType *, char *);
+  
+  // C++ handling
+
+  int    have_constructor;
+  int    have_destructor;
+  int    have_methods;
+  int    have_config;
+  int    have_cget;
+  String config;
+  String cget;
+  String methods;
+  String options;
+  String config_options;
+  String methodnames;
+  String postinit;
+  int    shadow;
+  char   *class_name;
+  char   *class_type;
+  char   *real_classname;
+  char   *base_class;
+  Hash   hash;
+  Hash   repeatcmd;
+
+  // C++ Code generation strings
+
+  String delcmd;
+  String methodcmd;
+  String objcmd;
+
 public :
     TCL() {
     prefix = 0;
@@ -71,27 +102,43 @@ public :
     safe_name = 0;
     Plugin = 0;
     nspace = 0;
+    shadow = 1;
     char_result = "TCL_VOLATILE";
     tcl_path = "tcl";
     sprintf(interp_name,"interp");
     sprintf(tcl_include,"tcl.h");
     sprintf(tk_include,"tk.h");
+    class_name = 0;
+    class_type = 0;
+    real_classname = 0;
+    base_class = 0;
   };
   void parse_args(int, char *argv[]);
   void parse();
   void create_function(char *, char *, DataType *, ParmList *);
   void link_variable(char *, char *, DataType *);
-  void declare_const(char *, DataType *, char *);
+  void declare_const(char *, char *, DataType *, char *);
   void initialize(void);
   void headers(void);
   void close(void);
-  void usage_var(char *, DataType *, char **);
-  void usage_func(char *, DataType *, ParmList *, char **);
-  void usage_const(char *, DataType *, char *, char **);
-  void set_module(char *);
+  void set_module(char *,char **);
   void set_init(char *);
   void add_native(char *, char *);
   void pragma(char *,char *, char *);
+  void create_command(char *, char *);
+
+  // Stubs for processing C++ classes in Tcl
+
+  void cpp_open_class(char *classname, char *rename, char *ctype, int strip);
+  void cpp_close_class();
+  void cpp_member_func(char *name, char *iname, DataType *t, ParmList *l);
+  void cpp_variable(char *name, char *iname, DataType *t);
+  void cpp_constructor(char *name, char *iname, ParmList *l);
+  void cpp_destructor(char *name, char *newname);
+  void cpp_inherit(char **baseclass, int mode = INHERIT_ALL);
+  void cpp_declare_const(char *name, char *iname, DataType *type, char *value);
+  void cpp_class_decl(char *, char *, char *);
+  void add_typedef(DataType *, char *);
 };
 
 
